@@ -3,4 +3,6 @@ from .anchorconflictresolutions import AnchorConflictResolutions
 from .aohmergeopts import AoHMergeOpts
 from .arraymergeopts import ArrayMergeOpts
 from .hashmergeopts import HashMergeOpts
+from .multidocmodes import MultiDocModes
 from .outputdoctypes import OutputDocTypes
+from .setmergeopts import SetMergeOpts
